@@ -9,7 +9,7 @@ use utf8;
 use Carp;
 use JSON::MaybeXS qw/JSON/;
 
-our $VERSION = "1.001000";
+our $VERSION = "1.002000";
 $VERSION = eval $VERSION;
 
 =encoding utf-8
@@ -165,6 +165,9 @@ file, I<may> be supplied. If you pass a directory, all JSON localization files
 in it will be loaded and merged as described above. If you pass one file,
 only that file will be loaded.
 
+Note that C<Locale::Wolowitz> will ignore dotfiles in the provided path (e.g.
+hidden files, backups files, etc.).
+
 =cut
 
 sub new {
@@ -210,7 +213,7 @@ sub load_path {
 			|| croak "Can't open localization directory: $!";
 	
 		# get all JSON files
-		@files = grep {/\.json$/} readdir PATH;
+		@files = grep {/^[^.].*\.json$/} readdir PATH;
 
 		closedir PATH
 			|| carp "Can't close localization directory: $!";
